// Code generated by protoc-gen-go. DO NOT EDIT.
// versions:
// 	protoc-gen-go v1.28.0
// 	protoc        (unknown)
// source: trade/subscribe.proto

package tradev1

import (
	protoreflect "google.golang.org/protobuf/reflect/protoreflect"
	protoimpl "google.golang.org/protobuf/runtime/protoimpl"
	reflect "reflect"
	sync "sync"
)

const (
	// Verify that this generated code is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(20 - protoimpl.MinVersion)
	// Verify that runtime/protoimpl is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(protoimpl.MaxVersion - 20)
)

// trade gateway command, see: https://open.longbridgeapp.com/docs/trade/trade-push
type Command int32

const (
	Command_CMD_UNKNOWN Command = 0
	Command_CMD_SUB     Command = 16
	Command_CMD_UNSUB   Command = 17
	Command_CMD_NOTIFY  Command = 18
)

// Enum value maps for Command.
var (
	Command_name = map[int32]string{
		0:  "CMD_UNKNOWN",
		16: "CMD_SUB",
		17: "CMD_UNSUB",
		18: "CMD_NOTIFY",
	}
	Command_value = map[string]int32{
		"CMD_UNKNOWN": 0,
		"CMD_SUB":     16,
		"CMD_UNSUB":   17,
		"CMD_NOTIFY":  18,
	}
)

func (x Command) Enum() *Command {
	p := new(Command)
	*p = x
	return p
}

func (x Command) String() string {
	return protoimpl.X.EnumStringOf(x.Descriptor(), protoreflect.EnumNumber(x))
}

func (Command) Descriptor() protoreflect.EnumDescriptor {
	return file_trade_subscribe_proto_enumTypes[0].Descriptor()
}

func (Command) Type() protoreflect.EnumType {
	return &file_trade_subscribe_proto_enumTypes[0]
}

func (x Command) Number() protoreflect.EnumNumber {
	return protoreflect.EnumNumber(x)
}

// Deprecated: Use Command.Descriptor instead.
func (Command) EnumDescriptor() ([]byte, []int) {
	return file_trade_subscribe_proto_rawDescGZIP(), []int{0}
}

// Dispatch type
type DispatchType int32

const (
	DispatchType_DISPATCH_UNDEFINED DispatchType = 0
	DispatchType_DISPATCH_DIRECT    DispatchType = 1
	DispatchType_DISPATCH_BROADCAST DispatchType = 2
)

// Enum value maps for DispatchType.
var (
	DispatchType_name = map[int32]string{
		0: "DISPATCH_UNDEFINED",
		1: "DISPATCH_DIRECT",
		2: "DISPATCH_BROADCAST",
	}
	DispatchType_value = map[string]int32{
		"DISPATCH_UNDEFINED": 0,
		"DISPATCH_DIRECT":    1,
		"DISPATCH_BROADCAST": 2,
	}
)

func (x DispatchType) Enum() *DispatchType {
	p := new(DispatchType)
	*p = x
	return p
}

func (x DispatchType) String() string {
	return protoimpl.X.EnumStringOf(x.Descriptor(), protoreflect.EnumNumber(x))
}

func (DispatchType) Descriptor() protoreflect.EnumDescriptor {
	return file_trade_subscribe_proto_enumTypes[1].Descriptor()
}

func (DispatchType) Type() protoreflect.EnumType {
	return &file_trade_subscribe_proto_enumTypes[1]
}

func (x DispatchType) Number() protoreflect.EnumNumber {
	return protoreflect.EnumNumber(x)
}

// Deprecated: Use DispatchType.Descriptor instead.
func (DispatchType) EnumDescriptor() ([]byte, []int) {
	return file_trade_subscribe_proto_rawDescGZIP(), []int{1}
}

type ContentType int32

const (
	ContentType_CONTENT_UNDEFINED ContentType = 0
	ContentType_CONTENT_JSON      ContentType = 1
	ContentType_CONTENT_PROTO     ContentType = 2
)

// Enum value maps for ContentType.
var (
	ContentType_name = map[int32]string{
		0: "CONTENT_UNDEFINED",
		1: "CONTENT_JSON",
		2: "CONTENT_PROTO",
	}
	ContentType_value = map[string]int32{
		"CONTENT_UNDEFINED": 0,
		"CONTENT_JSON":      1,
		"CONTENT_PROTO":     2,
	}
)

func (x ContentType) Enum() *ContentType {
	p := new(ContentType)
	*p = x
	return p
}

func (x ContentType) String() string {
	return protoimpl.X.EnumStringOf(x.Descriptor(), protoreflect.EnumNumber(x))
}

func (ContentType) Descriptor() protoreflect.EnumDescriptor {
	return file_trade_subscribe_proto_enumTypes[2].Descriptor()
}

func (ContentType) Type() protoreflect.EnumType {
	return &file_trade_subscribe_proto_enumTypes[2]
}

func (x ContentType) Number() protoreflect.EnumNumber {
	return protoreflect.EnumNumber(x)
}

// Deprecated: Use ContentType.Descriptor instead.
func (ContentType) EnumDescriptor() ([]byte, []int) {
	return file_trade_subscribe_proto_rawDescGZIP(), []int{2}
}

// Sub is Sub command content, command is 16
type Sub struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields

	Topics []string `protobuf:"bytes,1,rep,name=topics,proto3" json:"topics,omitempty"`
}

func (x *Sub) Reset() {
	*x = Sub{}
	if protoimpl.UnsafeEnabled {
		mi := &file_trade_subscribe_proto_msgTypes[0]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *Sub) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*Sub) ProtoMessage() {}

func (x *Sub) ProtoReflect() protoreflect.Message {
	mi := &file_trade_subscribe_proto_msgTypes[0]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use Sub.ProtoReflect.Descriptor instead.
func (*Sub) Descriptor() ([]byte, []int) {
	return file_trade_subscribe_proto_rawDescGZIP(), []int{0}
}

func (x *Sub) GetTopics() []string {
	if x != nil {
		return x.Topics
	}
	return nil
}

// SubResponse is response of Sub Request
type SubResponse struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields

	Success []string            `protobuf:"bytes,1,rep,name=success,proto3" json:"success,omitempty"` // 订阅成功
	Fail    []*SubResponse_Fail `protobuf:"bytes,2,rep,name=fail,proto3" json:"fail,omitempty"`       // 订阅失败
	Current []string            `protobuf:"bytes,3,rep,name=current,proto3" json:"current,omitempty"` // 当前订阅
}

func (x *SubResponse) Reset() {
	*x = SubResponse{}
	if protoimpl.UnsafeEnabled {
		mi := &file_trade_subscribe_proto_msgTypes[1]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *SubResponse) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*SubResponse) ProtoMessage() {}

func (x *SubResponse) ProtoReflect() protoreflect.Message {
	mi := &file_trade_subscribe_proto_msgTypes[1]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use SubResponse.ProtoReflect.Descriptor instead.
func (*SubResponse) Descriptor() ([]byte, []int) {
	return file_trade_subscribe_proto_rawDescGZIP(), []int{1}
}

func (x *SubResponse) GetSuccess() []string {
	if x != nil {
		return x.Success
	}
	return nil
}

func (x *SubResponse) GetFail() []*SubResponse_Fail {
	if x != nil {
		return x.Fail
	}
	return nil
}

func (x *SubResponse) GetCurrent() []string {
	if x != nil {
		return x.Current
	}
	return nil
}

// Unsub is Unsub command content, command is 17
type Unsub struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields

	Topics []string `protobuf:"bytes,1,rep,name=topics,proto3" json:"topics,omitempty"`
}

func (x *Unsub) Reset() {
	*x = Unsub{}
	if protoimpl.UnsafeEnabled {
		mi := &file_trade_subscribe_proto_msgTypes[2]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *Unsub) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*Unsub) ProtoMessage() {}

func (x *Unsub) ProtoReflect() protoreflect.Message {
	mi := &file_trade_subscribe_proto_msgTypes[2]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use Unsub.ProtoReflect.Descriptor instead.
func (*Unsub) Descriptor() ([]byte, []int) {
	return file_trade_subscribe_proto_rawDescGZIP(), []int{2}
}

func (x *Unsub) GetTopics() []string {
	if x != nil {
		return x.Topics
	}
	return nil
}

// UnsubResponse is response of Unsub request
type UnsubResponse struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields

	Current []string `protobuf:"bytes,3,rep,name=current,proto3" json:"current,omitempty"` // 当前订阅
}

func (x *UnsubResponse) Reset() {
	*x = UnsubResponse{}
	if protoimpl.UnsafeEnabled {
		mi := &file_trade_subscribe_proto_msgTypes[3]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *UnsubResponse) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*UnsubResponse) ProtoMessage() {}

func (x *UnsubResponse) ProtoReflect() protoreflect.Message {
	mi := &file_trade_subscribe_proto_msgTypes[3]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use UnsubResponse.ProtoReflect.Descriptor instead.
func (*UnsubResponse) Descriptor() ([]byte, []int) {
	return file_trade_subscribe_proto_rawDescGZIP(), []int{3}
}

func (x *UnsubResponse) GetCurrent() []string {
	if x != nil {
		return x.Current
	}
	return nil
}

// Notification is push message, command is 18
type Notification struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields

	Topic        string       `protobuf:"bytes,1,opt,name=topic,proto3" json:"topic,omitempty"`
	ContentType  ContentType  `protobuf:"varint,2,opt,name=content_type,json=contentType,proto3,enum=longbridgeapp.trade.v1.ContentType" json:"content_type,omitempty"`
	DispatchType DispatchType `protobuf:"varint,3,opt,name=dispatch_type,json=dispatchType,proto3,enum=longbridgeapp.trade.v1.DispatchType" json:"dispatch_type,omitempty"`
	Data         []byte       `protobuf:"bytes,4,opt,name=data,proto3" json:"data,omitempty"`
}

func (x *Notification) Reset() {
	*x = Notification{}
	if protoimpl.UnsafeEnabled {
		mi := &file_trade_subscribe_proto_msgTypes[4]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *Notification) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*Notification) ProtoMessage() {}

func (x *Notification) ProtoReflect() protoreflect.Message {
	mi := &file_trade_subscribe_proto_msgTypes[4]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use Notification.ProtoReflect.Descriptor instead.
func (*Notification) Descriptor() ([]byte, []int) {
	return file_trade_subscribe_proto_rawDescGZIP(), []int{4}
}

func (x *Notification) GetTopic() string {
	if x != nil {
		return x.Topic
	}
	return ""
}

func (x *Notification) GetContentType() ContentType {
	if x != nil {
		return x.ContentType
	}
	return ContentType_CONTENT_UNDEFINED
}

func (x *Notification) GetDispatchType() DispatchType {
	if x != nil {
		return x.DispatchType
	}
	return DispatchType_DISPATCH_UNDEFINED
}

func (x *Notification) GetData() []byte {
	if x != nil {
		return x.Data
	}
	return nil
}

type SubResponse_Fail struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields

	Topic  string `protobuf:"bytes,1,opt,name=topic,proto3" json:"topic,omitempty"`
	Reason string `protobuf:"bytes,2,opt,name=reason,proto3" json:"reason,omitempty"`
}

func (x *SubResponse_Fail) Reset() {
	*x = SubResponse_Fail{}
	if protoimpl.UnsafeEnabled {
		mi := &file_trade_subscribe_proto_msgTypes[5]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *SubResponse_Fail) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*SubResponse_Fail) ProtoMessage() {}

func (x *SubResponse_Fail) ProtoReflect() protoreflect.Message {
	mi := &file_trade_subscribe_proto_msgTypes[5]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use SubResponse_Fail.ProtoReflect.Descriptor instead.
func (*SubResponse_Fail) Descriptor() ([]byte, []int) {
	return file_trade_subscribe_proto_rawDescGZIP(), []int{1, 0}
}

func (x *SubResponse_Fail) GetTopic() string {
	if x != nil {
		return x.Topic
	}
	return ""
}

func (x *SubResponse_Fail) GetReason() string {
	if x != nil {
		return x.Reason
	}
	return ""
}

var File_trade_subscribe_proto protoreflect.FileDescriptor

var file_trade_subscribe_proto_rawDesc = []byte{
	0x0a, 0x15, 0x74, 0x72, 0x61, 0x64, 0x65, 0x2f, 0x73, 0x75, 0x62, 0x73, 0x63, 0x72, 0x69, 0x62,
	0x65, 0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x12, 0x16, 0x6c, 0x6f, 0x6e, 0x67, 0x62, 0x72, 0x69,
	0x64, 0x67, 0x65, 0x61, 0x70, 0x70, 0x2e, 0x74, 0x72, 0x61, 0x64, 0x65, 0x2e, 0x76, 0x31, 0x22,
	0x1d, 0x0a, 0x03, 0x53, 0x75, 0x62, 0x12, 0x16, 0x0a, 0x06, 0x74, 0x6f, 0x70, 0x69, 0x63, 0x73,
	0x18, 0x01, 0x20, 0x03, 0x28, 0x09, 0x52, 0x06, 0x74, 0x6f, 0x70, 0x69, 0x63, 0x73, 0x22, 0xb5,
	0x01, 0x0a, 0x0b, 0x53, 0x75, 0x62, 0x52, 0x65, 0x73, 0x70, 0x6f, 0x6e, 0x73, 0x65, 0x12, 0x18,
	0x0a, 0x07, 0x73, 0x75, 0x63, 0x63, 0x65, 0x73, 0x73, 0x18, 0x01, 0x20, 0x03, 0x28, 0x09, 0x52,
	0x07, 0x73, 0x75, 0x63, 0x63, 0x65, 0x73, 0x73, 0x12, 0x3c, 0x0a, 0x04, 0x66, 0x61, 0x69, 0x6c,
	0x18, 0x02, 0x20, 0x03, 0x28, 0x0b, 0x32, 0x28, 0x2e, 0x6c, 0x6f, 0x6e, 0x67, 0x62, 0x72, 0x69,
	0x64, 0x67, 0x65, 0x61, 0x70, 0x70, 0x2e, 0x74, 0x72, 0x61, 0x64, 0x65, 0x2e, 0x76, 0x31, 0x2e,
	0x53, 0x75, 0x62, 0x52, 0x65, 0x73, 0x70, 0x6f, 0x6e, 0x73, 0x65, 0x2e, 0x46, 0x61, 0x69, 0x6c,
	0x52, 0x04, 0x66, 0x61, 0x69, 0x6c, 0x12, 0x18, 0x0a, 0x07, 0x63, 0x75, 0x72, 0x72, 0x65, 0x6e,
	0x74, 0x18, 0x03, 0x20, 0x03, 0x28, 0x09, 0x52, 0x07, 0x63, 0x75, 0x72, 0x72, 0x65, 0x6e, 0x74,
	0x1a, 0x34, 0x0a, 0x04, 0x46, 0x61, 0x69, 0x6c, 0x12, 0x14, 0x0a, 0x05, 0x74, 0x6f, 0x70, 0x69,
	0x63, 0x18, 0x01, 0x20, 0x01, 0x28, 0x09, 0x52, 0x05, 0x74, 0x6f, 0x70, 0x69, 0x63, 0x12, 0x16,
	0x0a, 0x06, 0x72, 0x65, 0x61, 0x73, 0x6f, 0x6e, 0x18, 0x02, 0x20, 0x01, 0x28, 0x09, 0x52, 0x06,
	0x72, 0x65, 0x61, 0x73, 0x6f, 0x6e, 0x22, 0x1f, 0x0a, 0x05, 0x55, 0x6e, 0x73, 0x75, 0x62, 0x12,
	0x16, 0x0a, 0x06, 0x74, 0x6f, 0x70, 0x69, 0x63, 0x73, 0x18, 0x01, 0x20, 0x03, 0x28, 0x09, 0x52,
	0x06, 0x74, 0x6f, 0x70, 0x69, 0x63, 0x73, 0x22, 0x29, 0x0a, 0x0d, 0x55, 0x6e, 0x73, 0x75, 0x62,
	0x52, 0x65, 0x73, 0x70, 0x6f, 0x6e, 0x73, 0x65, 0x12, 0x18, 0x0a, 0x07, 0x63, 0x75, 0x72, 0x72,
	0x65, 0x6e, 0x74, 0x18, 0x03, 0x20, 0x03, 0x28, 0x09, 0x52, 0x07, 0x63, 0x75, 0x72, 0x72, 0x65,
	0x6e, 0x74, 0x22, 0xcb, 0x01, 0x0a, 0x0c, 0x4e, 0x6f, 0x74, 0x69, 0x66, 0x69, 0x63, 0x61, 0x74,
	0x69, 0x6f, 0x6e, 0x12, 0x14, 0x0a, 0x05, 0x74, 0x6f, 0x70, 0x69, 0x63, 0x18, 0x01, 0x20, 0x01,
	0x28, 0x09, 0x52, 0x05, 0x74, 0x6f, 0x70, 0x69, 0x63, 0x12, 0x46, 0x0a, 0x0c, 0x63, 0x6f, 0x6e,
	0x74, 0x65, 0x6e, 0x74, 0x5f, 0x74, 0x79, 0x70, 0x65, 0x18, 0x02, 0x20, 0x01, 0x28, 0x0e, 0x32,
	0x23, 0x2e, 0x6c, 0x6f, 0x6e, 0x67, 0x62, 0x72, 0x69, 0x64, 0x67, 0x65, 0x61, 0x70, 0x70, 0x2e,
	0x74, 0x72, 0x61, 0x64, 0x65, 0x2e, 0x76, 0x31, 0x2e, 0x43, 0x6f, 0x6e, 0x74, 0x65, 0x6e, 0x74,
	0x54, 0x79, 0x70, 0x65, 0x52, 0x0b, 0x63, 0x6f, 0x6e, 0x74, 0x65, 0x6e, 0x74, 0x54, 0x79, 0x70,
	0x65, 0x12, 0x49, 0x0a, 0x0d, 0x64, 0x69, 0x73, 0x70, 0x61, 0x74, 0x63, 0x68, 0x5f, 0x74, 0x79,
	0x70, 0x65, 0x18, 0x03, 0x20, 0x01, 0x28, 0x0e, 0x32, 0x24, 0x2e, 0x6c, 0x6f, 0x6e, 0x67, 0x62,
	0x72, 0x69, 0x64, 0x67, 0x65, 0x61, 0x70, 0x70, 0x2e, 0x74, 0x72, 0x61, 0x64, 0x65, 0x2e, 0x76,
	0x31, 0x2e, 0x44, 0x69, 0x73, 0x70, 0x61, 0x74, 0x63, 0x68, 0x54, 0x79, 0x70, 0x65, 0x52, 0x0c,
	0x64, 0x69, 0x73, 0x70, 0x61, 0x74, 0x63, 0x68, 0x54, 0x79, 0x70, 0x65, 0x12, 0x12, 0x0a, 0x04,
	0x64, 0x61, 0x74, 0x61, 0x18, 0x04, 0x20, 0x01, 0x28, 0x0c, 0x52, 0x04, 0x64, 0x61, 0x74, 0x61,
	0x2a, 0x46, 0x0a, 0x07, 0x43, 0x6f, 0x6d, 0x6d, 0x61, 0x6e, 0x64, 0x12, 0x0f, 0x0a, 0x0b, 0x43,
	0x4d, 0x44, 0x5f, 0x55, 0x4e, 0x4b, 0x4e, 0x4f, 0x57, 0x4e, 0x10, 0x00, 0x12, 0x0b, 0x0a, 0x07,
	0x43, 0x4d, 0x44, 0x5f, 0x53, 0x55, 0x42, 0x10, 0x10, 0x12, 0x0d, 0x0a, 0x09, 0x43, 0x4d, 0x44,
	0x5f, 0x55, 0x4e, 0x53, 0x55, 0x42, 0x10, 0x11, 0x12, 0x0e, 0x0a, 0x0a, 0x43, 0x4d, 0x44, 0x5f,
	0x4e, 0x4f, 0x54, 0x49, 0x46, 0x59, 0x10, 0x12, 0x2a, 0x53, 0x0a, 0x0c, 0x44, 0x69, 0x73, 0x70,
	0x61, 0x74, 0x63, 0x68, 0x54, 0x79, 0x70, 0x65, 0x12, 0x16, 0x0a, 0x12, 0x44, 0x49, 0x53, 0x50,
	0x41, 0x54, 0x43, 0x48, 0x5f, 0x55, 0x4e, 0x44, 0x45, 0x46, 0x49, 0x4e, 0x45, 0x44, 0x10, 0x00,
	0x12, 0x13, 0x0a, 0x0f, 0x44, 0x49, 0x53, 0x50, 0x41, 0x54, 0x43, 0x48, 0x5f, 0x44, 0x49, 0x52,
	0x45, 0x43, 0x54, 0x10, 0x01, 0x12, 0x16, 0x0a, 0x12, 0x44, 0x49, 0x53, 0x50, 0x41, 0x54, 0x43,
	0x48, 0x5f, 0x42, 0x52, 0x4f, 0x41, 0x44, 0x43, 0x41, 0x53, 0x54, 0x10, 0x02, 0x2a, 0x49, 0x0a,
	0x0b, 0x43, 0x6f, 0x6e, 0x74, 0x65, 0x6e, 0x74, 0x54, 0x79, 0x70, 0x65, 0x12, 0x15, 0x0a, 0x11,
	0x43, 0x4f, 0x4e, 0x54, 0x45, 0x4e, 0x54, 0x5f, 0x55, 0x4e, 0x44, 0x45, 0x46, 0x49, 0x4e, 0x45,
	0x44, 0x10, 0x00, 0x12, 0x10, 0x0a, 0x0c, 0x43, 0x4f, 0x4e, 0x54, 0x45, 0x4e, 0x54, 0x5f, 0x4a,
	0x53, 0x4f, 0x4e, 0x10, 0x01, 0x12, 0x11, 0x0a, 0x0d, 0x43, 0x4f, 0x4e, 0x54, 0x45, 0x4e, 0x54,
	0x5f, 0x50, 0x52, 0x4f, 0x54, 0x4f, 0x10, 0x02, 0x42, 0xe7, 0x01, 0x0a, 0x1a, 0x63, 0x6f, 0x6d,
	0x2e, 0x6c, 0x6f, 0x6e, 0x67, 0x62, 0x72, 0x69, 0x64, 0x67, 0x65, 0x61, 0x70, 0x70, 0x2e, 0x74,
	0x72, 0x61, 0x64, 0x65, 0x2e, 0x76, 0x31, 0x42, 0x0e, 0x53, 0x75, 0x62, 0x73, 0x63, 0x72, 0x69,
	0x62, 0x65, 0x50, 0x72, 0x6f, 0x74, 0x6f, 0x50, 0x01, 0x5a, 0x3f, 0x67, 0x69, 0x74, 0x68, 0x75,
	0x62, 0x2e, 0x63, 0x6f, 0x6d, 0x2f, 0x6c, 0x6f, 0x6e, 0x67, 0x62, 0x72, 0x69, 0x64, 0x67, 0x65,
	0x61, 0x70, 0x70, 0x2f, 0x6f, 0x70, 0x65, 0x6e, 0x61, 0x70, 0x69, 0x2d, 0x70, 0x72, 0x6f, 0x74,
	0x6f, 0x62, 0x75, 0x66, 0x73, 0x2f, 0x67, 0x65, 0x6e, 0x2f, 0x67, 0x6f, 0x2f, 0x74, 0x72, 0x61,
	0x64, 0x65, 0x3b, 0x74, 0x72, 0x61, 0x64, 0x65, 0x76, 0x31, 0xa2, 0x02, 0x03, 0x4c, 0x54, 0x58,
	0xaa, 0x02, 0x16, 0x4c, 0x6f, 0x6e, 0x67, 0x62, 0x72, 0x69, 0x64, 0x67, 0x65, 0x61, 0x70, 0x70,
	0x2e, 0x54, 0x72, 0x61, 0x64, 0x65, 0x2e, 0x56, 0x31, 0xca, 0x02, 0x16, 0x4c, 0x6f, 0x6e, 0x67,
	0x62, 0x72, 0x69, 0x64, 0x67, 0x65, 0x61, 0x70, 0x70, 0x5c, 0x54, 0x72, 0x61, 0x64, 0x65, 0x5c,
	0x56, 0x31, 0xe2, 0x02, 0x22, 0x4c, 0x6f, 0x6e, 0x67, 0x62, 0x72, 0x69, 0x64, 0x67, 0x65, 0x61,
	0x70, 0x70, 0x5c, 0x54, 0x72, 0x61, 0x64, 0x65, 0x5c, 0x56, 0x31, 0x5c, 0x47, 0x50, 0x42, 0x4d,
	0x65, 0x74, 0x61, 0x64, 0x61, 0x74, 0x61, 0xea, 0x02, 0x18, 0x4c, 0x6f, 0x6e, 0x67, 0x62, 0x72,
	0x69, 0x64, 0x67, 0x65, 0x61, 0x70, 0x70, 0x3a, 0x3a, 0x54, 0x72, 0x61, 0x64, 0x65, 0x3a, 0x3a,
	0x56, 0x31, 0x62, 0x06, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x33,
}

var (
	file_trade_subscribe_proto_rawDescOnce sync.Once
	file_trade_subscribe_proto_rawDescData = file_trade_subscribe_proto_rawDesc
)

func file_trade_subscribe_proto_rawDescGZIP() []byte {
	file_trade_subscribe_proto_rawDescOnce.Do(func() {
		file_trade_subscribe_proto_rawDescData = protoimpl.X.CompressGZIP(file_trade_subscribe_proto_rawDescData)
	})
	return file_trade_subscribe_proto_rawDescData
}

var file_trade_subscribe_proto_enumTypes = make([]protoimpl.EnumInfo, 3)
var file_trade_subscribe_proto_msgTypes = make([]protoimpl.MessageInfo, 6)
var file_trade_subscribe_proto_goTypes = []interface{}{
	(Command)(0),             // 0: longbridgeapp.trade.v1.Command
	(DispatchType)(0),        // 1: longbridgeapp.trade.v1.DispatchType
	(ContentType)(0),         // 2: longbridgeapp.trade.v1.ContentType
	(*Sub)(nil),              // 3: longbridgeapp.trade.v1.Sub
	(*SubResponse)(nil),      // 4: longbridgeapp.trade.v1.SubResponse
	(*Unsub)(nil),            // 5: longbridgeapp.trade.v1.Unsub
	(*UnsubResponse)(nil),    // 6: longbridgeapp.trade.v1.UnsubResponse
	(*Notification)(nil),     // 7: longbridgeapp.trade.v1.Notification
	(*SubResponse_Fail)(nil), // 8: longbridgeapp.trade.v1.SubResponse.Fail
}
var file_trade_subscribe_proto_depIdxs = []int32{
	8, // 0: longbridgeapp.trade.v1.SubResponse.fail:type_name -> longbridgeapp.trade.v1.SubResponse.Fail
	2, // 1: longbridgeapp.trade.v1.Notification.content_type:type_name -> longbridgeapp.trade.v1.ContentType
	1, // 2: longbridgeapp.trade.v1.Notification.dispatch_type:type_name -> longbridgeapp.trade.v1.DispatchType
	3, // [3:3] is the sub-list for method output_type
	3, // [3:3] is the sub-list for method input_type
	3, // [3:3] is the sub-list for extension type_name
	3, // [3:3] is the sub-list for extension extendee
	0, // [0:3] is the sub-list for field type_name
}

func init() { file_trade_subscribe_proto_init() }
func file_trade_subscribe_proto_init() {
	if File_trade_subscribe_proto != nil {
		return
	}
	if !protoimpl.UnsafeEnabled {
		file_trade_subscribe_proto_msgTypes[0].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*Sub); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
		file_trade_subscribe_proto_msgTypes[1].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*SubResponse); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
		file_trade_subscribe_proto_msgTypes[2].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*Unsub); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
		file_trade_subscribe_proto_msgTypes[3].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*UnsubResponse); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
		file_trade_subscribe_proto_msgTypes[4].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*Notification); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
		file_trade_subscribe_proto_msgTypes[5].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*SubResponse_Fail); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
	}
	type x struct{}
	out := protoimpl.TypeBuilder{
		File: protoimpl.DescBuilder{
			GoPackagePath: reflect.TypeOf(x{}).PkgPath(),
			RawDescriptor: file_trade_subscribe_proto_rawDesc,
			NumEnums:      3,
			NumMessages:   6,
			NumExtensions: 0,
			NumServices:   0,
		},
		GoTypes:           file_trade_subscribe_proto_goTypes,
		DependencyIndexes: file_trade_subscribe_proto_depIdxs,
		EnumInfos:         file_trade_subscribe_proto_enumTypes,
		MessageInfos:      file_trade_subscribe_proto_msgTypes,
	}.Build()
	File_trade_subscribe_proto = out.File
	file_trade_subscribe_proto_rawDesc = nil
	file_trade_subscribe_proto_goTypes = nil
	file_trade_subscribe_proto_depIdxs = nil
}
